Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Configuration represent the variable of configuration model Configuration = &ConfigurationModel{} )
Functions ¶
func InitKafkaProducer ¶
func InitKafkaProducer() (sarama.AsyncProducer, error)
InitKafkaProducer will create a variable that represent the sarama.AsyncProducer
Types ¶
type ConfigurationModel ¶
type ConfigurationModel struct {
Port string `json:"port"`
Kafka struct {
Addr string `json:"addr"`
} `json:"kafka"`
}
ConfigurationModel represent the configuration model
Click to show internal directories.
Click to hide internal directories.